#!/usr/bin/env python3

import gpiod
import time
from .sim_selector import SimSelector
from .exceptions import NoSimException


class SimSelectorSingleSwitch(SimSelector):
    sim_sw = gpiod.find_line('SIM_SW')
    sim_map = {}

    def __init__(self, sim_map, sim='main'):
        self.sim_map = sim_map
        try:
            sim_value = sim_map[sim]
        except Exception:
            raise Exception('Sim {} not found'.format(sim))

        self.sim_sw.request(consumer='sim-sel',
                            type=gpiod.LINE_REQ_DIR_OUT,
                            default_vals=[sim_value])

    def switch_sim(self):
        value = self.sim_sw.get_value()
        self.sim_sw.set_value((value + 1) % 2)

    # Returns true if a reload is required
    def connect(self, sim):
        if self.sim_sw.get_value() != self.sim_map[sim]:
            self.switch_sim()
            return True
        return False

    # Returns true if a reload is required
    def auto_connect(self, modem):
        # We allow up to 5 errors while reading the sim card
        # Because some sims are making the modem having a hard time
        # These sims are however still identified at the 3rd attempt
        allowed_errors = 5
        while allowed_errors > 0:
            try:
                modem.get_sim_id()
                return False
            except NoSimException:
                time.sleep(1)
                allowed_errors  -= 1

        self.switch_sim()
        return True
