#!/usr/bin/env python3

import configparser
import os
from shutil import copyfile

from .logger import logger

SETUP_PATH = '/etc/wwan/'
APN_FILE = '/etc/apn.conf'
SIM_FILE = '/etc/sim.conf'


def migrate_config(device):
    apn = None
    user = None
    password = None
    sim = None

    # Get old APN config
    if os.path.exists(APN_FILE):
        apn_config = configparser.ConfigParser()
        apn_config.read(APN_FILE)
        if apn_config.has_option('default', 'apn'):
            apn = apn_config.get('default', 'apn')
        if apn_config.has_option('default', 'user'):
            user = apn_config.get('default', 'user')
        if apn_config.has_option('default', 'password'):
            password = apn_config.get('default', 'password')

    # Get old SIM config
    if os.path.exists(SIM_FILE):
        sim_config = configparser.ConfigParser()
        sim_config.read(SIM_FILE)

        if sim_config.has_option('default', 'SIM'):
            sim = sim_config.get('default', 'SIM')

        if sim == "esim":
            sim = "m2m"
        elif sim == "main":
            sim = "sim1"

    if not any((apn, user, password, sim)):
        return  # No old config

    # Get new config
    new_config_path = SETUP_PATH + device + ".conf"
    new_config = configparser.ConfigParser()
    new_config.read_file(open(new_config_path))

    # Update new config with old values
    if apn is not None:
        new_config.set('apn', 'apn', apn)
    if user is not None:
        new_config.set('apn', 'user', user)
    if password is not None:
        new_config.set('apn', 'password', password)
    if sim is not None:
        new_config.set('sim', 'SIM', sim)

    copyfile(new_config_path, new_config_path + '.template')
    with open(new_config_path, 'w+') as new_config_file:
        new_config.write(new_config_file, False)

    # Remove old config files
    if os.path.exists(SIM_FILE):
        os.remove(SIM_FILE)
    if os.path.exists(APN_FILE):
        os.remove(APN_FILE)

    logger.info("Config file migration successful")


if __name__ == '__main__':
    migrate_config('wwan0')
