""" ModemManager monitoring interface """

import os
import time

from .logger import logger

class ModemManagerException(Exception):
    """ ModemManager failed to identify modem  """

class ModemManager():
    """ ModemManager monitoring interface """
    err_cnt = 0

    def monitor(self):
        """ Monitor MM, trying to restart it if in unexpected state """
        if self.is_modem_ready():
            self.err_cnt = 0
            return

        self.err_cnt += 1
        if self.err_cnt <= 3:
            self.restart()
        else:
            self.err_cnt = 0
            raise ModemManagerException()

    @staticmethod
    def is_modem_ready():
        """ Return true if the modem is properly detected by MM """
        return os.system('mmcli -m 0 >/dev/null 2>/dev/null') == 0

    @staticmethod
    def restart():
        """ Restart ModemManager """
        ModemManager.stop()
        ModemManager.start()

    @staticmethod
    def start():
        """ Start ModemManager """
        logger.info("Starting ModemManager")
        os.system('systemctl start ModemManager')

    @staticmethod
    def monitor_startup():
        """ Start MM and wait until the modem is discovered, ev. restarting MM after a delay """
        ModemManager.start()
        # Wait until modem is ready
        mm_restarts = 2
        while True:
            logger.info("waiting on mm start")
            timeout = 20
            while True:
                time.sleep(1)
                if ModemManager.is_modem_ready():
                    return
                timeout = timeout - 1
                if timeout == 0:
                    break

            if mm_restarts == 0:
                logger.error("Modem not found by MM after multiple restart")
                raise ModemManagerException()
            else:
                logger.warning("Modem not found by MM, restarting ModemManager")
                ModemManager.restart()
                mm_restarts -= 1


    @staticmethod
    def stop():
        """ Stop ModemManager """
        logger.info("Stoppping ModemManager")
        os.system('systemctl stop ModemManager')
